# Copyright 2018-2013, Agriculture and Biology
# Author: Sai Wang
#
# This code is part of the aimap package, and is governed by its licence.
# Please see the LICENSE file that should have been included as part of
# this package.

"""Configuration settings for the aimap package.
"""


# Defaults assume that common binaries are on the $PATH
TRIM_GALORE_DEFAULT = "trim_galore"
BWA_DEFAULT = "bwa"
SAMTOOLS_DEFAULT = "samtools"
BCFTOOLS_DEFAULT = "bcftools"



# Copyright 2018-2023, Agriculture and Biology
# Author: sai wang
#
# This code is part of the aimap package, and is governed by its licence.
# Please see the LICENSE file that should have been included as part of
# this package.

import os
import shutil
import gffutils

import pandas as pd

from Bio import SeqIO
from Bio.Seq import MutableSeq
from Bio.Seq import Seq
#from Bio.Alphabet import IUPAC
from Bio.SeqRecord import SeqRecord
from . import aimap_config
import bisect

# Generate single TRIM_GALORE command line
def construct_trim_galore_single_cmdline(outdir,length,fname,
                               trim_galore_exe=aimap_config.TRIM_GALORE_DEFAULT):
    """Returns a single trim_galore command.

    - trim_galore_exe - path to TRIM_GALORE executable
    """
    cmd="{0} -O {1} -q 30 --phred33 --trim-n --length {2} {3}"
    return cmd.format(trim_galore_exe, outdir, length, fname)


def construct_trim_galore_paired_cmdline(outdir,length,fname1,fname2,
                               trim_galore_exe=aimap_config.TRIM_GALORE_DEFAULT):
    """Returns a paired trim_galore command.

    - trim_galore_exe - path to TRIM_GALORE executable
    """
    cmd="{0} -O {1} -q 30 --phred33 --trim-n --length {2} --paired {3} {4}"
    return cmd.format(trim_galore_exe, outdir, length, fname1,fname2)


def construct_bwa_index_cmdline(fname, bwa_exe=aimap_config.BWA_DEFAULT):
    cmd = "{0} index {1}"
    return cmd.format(bwa_exe, fname)


def construct_bwa_mem_single_cmdline(genome,fqfile,outdir,outname,threads,bwa_exe=aimap_config.BWA_DEFAULT):
    cmd = "{0} mem {1} {2} -t {3} -o {4}/{5}.sam"
    return cmd.format(bwa_exe, genome,fqfile,threads,outdir,outname)


def construct_bwa_mem_paired_cmdline(genome,fqfile1,fqfile2,outdir,outname,threads,bwa_exe=aimap_config.BWA_DEFAULT):
    cmd = "{0} mem {1} {2} {3} -t {4} -o {5}/{6}.sam"
    return cmd.format(bwa_exe, genome,fqfile1,fqfile2,threads,outdir,outname)

def construct_samtools_sort_cmdline(insamfile,outdir,outname,threads,samtools_exe=aimap_config.SAMTOOLS_DEFAULT):
    cmd = "{0} sort -@ {1} -o {2}/{3}-sorted.bam {4}"
    return cmd.format(samtools_exe,threads,outdir,outname, insamfile)
    
def construct_bcftools_mpileup_cmdline(sorted_bamfile,genome,outdir,outname,threads,bcftools_exe=aimap_config.BCFTOOLS_DEFAULT):
    cmd = "{0} mpileup --threads {1} -d 50000 -f {2} {3} -o {4}/{5}.bcf"
    return cmd.format(bcftools_exe,threads,genome, sorted_bamfile,outdir,outname)
    
def construct_bcftools_call_cmdline(inbcffile,outdir,outname,threads,bcftools_exe=aimap_config.BCFTOOLS_DEFAULT):
    cmd = "{0} call -m -v -o {1}/{2}.vcf -O v --threads {3} {4}"
    return cmd.format(bcftools_exe,outdir,outname,threads, inbcffile)

def construct_bcftools_view_cmdline(invcffile,outdir,outname,threads,bcftools_exe=aimap_config.BCFTOOLS_DEFAULT):
    cmd = "{0} view --types snps -o {1}/{2}-filt.vcf -O v --threads {3} {4}"
    return cmd.format(bcftools_exe, outdir,outname,threads,invcffile)
    
def construct_bcftools_query_cmdline(invcffile,outdir,outname,bcftools_exe=aimap_config.BCFTOOLS_DEFAULT):
    cmd = "{0} query -f '%CHROM\t%POS\t%REF\t%ALT\t%DP\t%DP4\n' {1} >{2}/{3}.tab"
    return cmd.format(bcftools_exe, invcffile,outdir,outname)


def convert_pileup_to_table(infile,outdir,outname):
    outfile = open("%s/%s_modification.txt" % (outdir, outname),"w")
    with open('%s'% infile, 'r') as pileup:
        data=pileup.readlines()
        data=filter(None, data)
        for line in data:
            linsplit=line.strip().split("\t")
            r_al=int(linsplit[-1].split(",")[2])
            l_al=int(linsplit[-1].split(",")[3])
            t_al=r_al+l_al
            r_ref=int(linsplit[-1].split(",")[0])
            l_ref=int(linsplit[-1].split(",")[1])
            h_t=r_ref+l_ref+t_al
            if (linsplit[2]=="A" or linsplit[2]=="a") and (linsplit[3]=="G" or linsplit[3]=="g"):
                outfile.write(linsplit[0]+"\t"+linsplit[1]+"\t"+linsplit[2]+"\t"+linsplit[3]+"\t"+linsplit[4]+"\t"+str(h_t)+"\t"+str(t_al/float(h_t))+"\t"+str(t_al)+"\t"+str(r_al)+"\t"+str(l_al)+"\n")
            if (linsplit[2]=="T" or linsplit[2]=="t") and ((linsplit[3]=="C" or linsplit[3]=="c")):
                outfile.write(linsplit[0]+"\t"+linsplit[1]+"\t"+linsplit[2]+"\t"+linsplit[3]+"\t"+linsplit[4]+"\t"+str(h_t)+"\t"+str(t_al/float(h_t))+"\t"+str(t_al)+"\t"+str(r_al)+"\t"+str(l_al)+"\n")
            if (linsplit[2]=="C" or linsplit[2]=="c") and (linsplit[3]=="T" or linsplit[3]=="t"):
                outfile.write(linsplit[0]+"\t"+linsplit[1]+"\t"+linsplit[2]+"\t"+linsplit[3]+"\t"+linsplit[4]+"\t"+str(h_t)+"\t"+str(t_al/float(h_t))+"\t"+str(t_al)+"\t"+str(r_al)+"\t"+str(l_al)+"\n")
            if (linsplit[2]=="G" or linsplit[2]=="g") and ((linsplit[3]=="A" or linsplit[3]=="a")):
                outfile.write(linsplit[0]+"\t"+linsplit[1]+"\t"+linsplit[2]+"\t"+linsplit[3]+"\t"+linsplit[4]+"\t"+str(h_t)+"\t"+str(t_al/float(h_t))+"\t"+str(t_al)+"\t"+str(r_al)+"\t"+str(l_al)+"\n") 
    outfile.close()

def get_founction_Prokaryote(infile,outdir,outname,genomefile,anno_file):
    result_file=open("%s/%s_full_result.txt"%(outdir,outname),"w")
    result_file.write("Accession"+"\t"+"Position"+"\t"+"Old_base"+"\t"+"New_base"+"\t"+"Raw read depth"+"\t"+"Coverage"+"\t"+"Edit_level"+
                  "\t"+"snp_coverage"+"\t"+"snp_f_coverage"+"\t"+"snp_r_coverage"+"\t"+"Gene_biotype"+"\t"+"Gene_name"+"\t"+"Gene_strand"+"\t"+"Product"+
                  "\t"+"Amino acid_change"+"\n")
    db = gffutils.create_db("%s"% anno_file, ':memory:', force=True, keep_order=True,merge_strategy='merge', id_spec="ID",sort_attribute_values=True)
    start=[db[i.id].start for i in db.all_features(featuretype='gene')]
    end=[db[i.id].end for i in db.all_features(featuretype='gene')]
    id_list=[i.id for i in db.all_features(featuretype='gene')]
    with open('%s'% infile, 'r') as pileup:
        data=pileup.readlines()
        data=filter(None, data)
        for line in data:
            linsplit=line.strip().split("\t")
            accession=linsplit[0]
            position=int(linsplit[1])
            oldbase=linsplit[2]
            newbase=linsplit[3]
            idx = bisect.bisect_left(end, position)
            if idx < len(end) and start[idx] <= position <= end[idx]:
                id=id_list[idx]
                if db[id].seqid == accession and db[id].attributes['gene_biotype'][0]=="protein_coding":
                    if db[id].strand== "+":
                        if (oldbase=="A" or oldbase=="a") and (newbase=="G" or oldbase=="g"):
                            change_loc=position-db[id].start
                            old_seq=Seq(db[id].sequence("%s"% genomefile, use_strand=False))
                            new_seq = MutableSeq(old_seq)
                            new_seq[change_loc] = newbase
                            new_seq=Seq(new_seq)
                            CDS_id=[h.id for h in db.children(id,featuretype="CDS")][0]
                            product=db[CDS_id].attributes['product'][0]
                            old_pro=old_seq.translate()
                            new_pro=new_seq.translate()
                            if old_pro==new_pro:
                                result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"
                                                              +str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+"CDS"+"\t"+db[id].attributes['Name'][0]
                                                              +"\t"+"+"+"\t"+str(product)+"\t"+"no change"+"\n")
                            else:
                                for n in range(len(old_pro)):
                                    if old_pro[n]==new_pro[n]:
                                        pass
                                    else:
                                        result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"
                                                              +str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+"CDS"+"\t"+db[id].attributes['Name'][0]
                                                              +"\t"+"+"+"\t"+str(product)+"\t"+old_pro[n]+str(n+1)+new_pro[n]+"\n")
                    if db[id].strand== "-" :
                        if (oldbase=="T" or oldbase=="t") and (newbase=="C" or newbase=="c"):
                            change_loc=position-db[id].start
                            old_seq=Seq(db[id].sequence("%s"% genomefile, use_strand=False))
                            new_seq = MutableSeq(old_seq)
                            new_seq[change_loc] = newbase
                            new_seq=Seq(new_seq)
                            CDS_id=[h.id for h in db.children(id,featuretype="CDS")][0]
                            product=db[CDS_id].attributes['product'][0]
                            old_seq=old_seq.reverse_complement()
                            new_seq=new_seq.reverse_complement()
                            old_pro=old_seq.translate()
                            new_pro=new_seq.translate()
                            if old_pro==new_pro:
                                result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"
                                                              +str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+"CDS"+"\t"+db[id].attributes['Name'][0]
                                                              +"\t"+"+"+"\t"+str(product)+"\t"+"no change"+"\n")                            
                            else:
                                for n in range(len(old_pro)):
                                    if old_pro[n]==new_pro[n]:
                                        pass
                                    else:
                                        result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"
                                                              +str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+"CDS"+"\t"+db[id].attributes['Name'][0]
                                                              +"\t"+"-"+"\t"+str(product)+"\t"+old_pro[n]+str(n+1)+new_pro[n]+"\n")
                if db[id].seqid == accession and db[id].attributes['gene_biotype'][0]!="protein_coding":
                    result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"+str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+db[id].attributes['gene_biotype'][0]+"\t"+db[id].attributes['Name'][0]+"\t"+" "+"\t"+" "+"\t"+" "+"\n")
            else:
                if ((oldbase=="T" or oldbase=="t") and (newbase=="C" or newbase=="c")) or ((oldbase=="A" or oldbase=="a") and (newbase=="G" or oldbase=="g")):
                    result_file.write(str(accession)+"\t"+str(position)+"\t"+str(oldbase)+"\t"+str(newbase)+"\t"+str(linsplit[4])+"\t"+str(linsplit[5])+"\t"+str(linsplit[6])+"\t"+str(linsplit[7])
                                                              +"\t"+str(linsplit[8])+"\t"+str(linsplit[9])+"\t"+"Intergenic region"+"\t"+" "+"\t"+" "+"\t"+" "+"\t"+" "+"\n")
    result_file.close()



#!/usr/bin/python3
#
# Adenosine_to_inosine.py
#
# This code is part of the aimap package, and is governed by its licence.
# Please see the LICENSE file that should have been included as part of
# this package.

import json
import logging
import logging.handlers
import os
import subprocess
import pandas as pd
import gffutils
import random
import shutil
import sys
import tarfile
import time
import traceback
from argparse import ArgumentParser

from aimap import (aimap_tools, aimap_config)
from aimap import __version__ as VERSION


# Process command-line arguments
def parse_cmdline():
    """Parse command-line arguments for script."""
    parser = ArgumentParser(prog="Adenosine_to_inosine.py")
    parser.add_argument('--version', action='version',
                        version='%(prog)s: aimap ' + VERSION)
    parser.add_argument("-o", "--outdir", dest="outdirname",
                        action="store", default=None, required=True,
                        help="Output directory (required)")
    parser.add_argument("-g", "--genome", dest="genomename",
                        action="store", default=None, required=True,
                        help="Genome file name (required)")
    parser.add_argument("-a", "--annotation", dest="annotation",
                        action="store", default=None,required=True,
                        help="Genome annotation file, gff3 format")
    parser.add_argument("--outfile_name", dest="outfile_name",
                        action="store", default=None,required=True,
                        help="output file name")
    parser.add_argument( "-l","--length", dest="length",
                        action="store", default=80,
                        help="Discard reads that became shorter than length INT because of either quality or adapter trimming. A value of '0' effectively disables this behaviour. Default: 80 bp.")
    parser.add_argument("-f", "--filename", dest="filename",
                        action="store", default=None,
                        help="Fastq file if model is single")
    parser.add_argument("-f1", "--filename1", dest="filename1",
                        action="store", default=None,
                        help="Fastq1 file if model is paired")
    parser.add_argument("-f2", "--filename2", dest="filename2",
                        action="store", default=None,
                        help="Fastq2 file if model is paired")
    parser.add_argument("-m", "--model", dest="model",
                        action="store", default="paired",
                        choices=["single", "paired"],
                        help="aimap model (default paired)")
    parser.add_argument("-t", "--threads", dest="threads",
                        action="store", default=1,
                        help="Number of additional threads to use (default 1)")
    parser.add_argument("--logfile", dest="logfile",
                        action="store", default=None,
                        help="Logfile location")
    return parser.parse_args()

	# Report last exception as string
def last_exception():
    """ Returns last exception as a string, or use in logging.
    """
    exc_type, exc_value, exc_traceback = sys.exc_info()
    return ''.join(traceback.format_exception(exc_type, exc_value,
                                              exc_traceback))
											
# Create output directory if it doesn't exist
def make_outdir():
    """Make the output directory, if required.

    This is a little involved.  If the output directory already exists,
    we take the safe option by default, and stop with an error.  We can,
    however, choose to force the program to go on, in which case we can
    either clobber the existing directory, or not.  The options turn out
    as the following, if the directory exists:

    DEFAULT: stop and report the collision
    FORCE: continue, and remove the existing output directory
    NOCLOBBER+FORCE: continue, but do not remove the existing output
    """
    if os.path.exists(args.outdirname):
        logger.error("Output directory %s would overwrite existing " +
                         "files (exiting)", args.outdirname)
        sys.exit(1)
    else:
        logger.info("Creating directory %s", args.outdirname)
        os.makedirs(args.outdirname)
			
# Run as script
if __name__ == '__main__':

    # Parse command-line
    args = parse_cmdline()
	
	# Set up logging
    logger = logging.getLogger('aimap.py: %s' %
                               time.asctime())
    t0 = time.time()
    logger.setLevel(logging.DEBUG)
    err_handler = logging.StreamHandler(sys.stderr)
    err_formatter = logging.Formatter('%(levelname)s: %(message)s')
    err_handler.setFormatter(err_formatter)
	
	# Was a logfile specified? If so, use it
    if args.logfile is not None:
        try:
            logstream = open(args.logfile, 'w')
            err_handler_file = logging.StreamHandler(logstream)
            err_handler_file.setFormatter(err_formatter)
            err_handler_file.setLevel(logging.INFO)
            logger.addHandler(err_handler_file)
        except:
            logger.error("Could not open %s for logging",
                         args.logfile)
            sys.exit(1)
			
	# Have we got required args? If not, exit.
    if args.genomename is None:
        logger.error("No genome file name (exiting)")
        sys.exit(1)
    if args.annotation is None:
        logger.error("No annotation file (exiting)")
        sys.exit(1)
    if args.outfile_name is None:
        logger.error("No outfile name (exiting)")
        sys.exit(1)
    make_outdir()
    logger.info("Output directory: %s", args.outdirname)

    #Step1 Apply adapter and quality trimming to FastQ files.
    logger.info("Step1 Apply adapter and quality trimming to FastQ files.")
    if args.model == "single":
        if args.filename is None:
            logger.error("No fastq file name (exiting)")
            sys.exit(1)
        else:
            os.system(aimap_tools.construct_trim_galore_single_cmdline(args.outdirname,args.length,args.filename))
    if args.model == "paired":
        if args.filename1 is None:
            logger.error("No required fastq file1 name (exiting)")
            sys.exit(1)
        elif args.filename2 is None:
            logger.error("No required fastq file2 name (exiting)")
            sys.exit(1)
        else:
           os.system(aimap_tools.construct_trim_galore_paired_cmdline(args.outdirname,args.length,args.filename1,args.filename2))
							
    #Step2 Index genome sequences in the FASTA format.
    logger.info("Step2 Index sequences in the FASTA format.")
    os.system(aimap_tools.construct_bwa_index_cmdline(args.genomename))
	
    #Step3 Map reads to genome.
    logger.info("Step3 Map reads to genome.")
    if args.model == "single":
        old_file=os.path.splitext(os.path.split(args.filename)[1])[0]
        new_file=args.outdirname+"/"+old_file+"_trimmed.fq"
        os.system(aimap_tools.construct_bwa_mem_single_cmdline(args.genomename, new_file,args.outdirname,args.outfile_name,args.threads))
        
        #Step4 Sort the bam file.
        logger.info("Step4 Sort the bam file.")
        insamfile=args.outdirname+"/"+args.outfile_name+".sam"        
        os.system(aimap_tools.construct_samtools_sort_cmdline(insamfile,args.outdirname,args.outfile_name,args.threads)) 
                        
        #Step5 Generate bcf for one or multiple BAM files
        logger.info("Generate bcf for one or multiple BAM files")
        inbamfile=args.outdirname+"/"+args.outfile_name+"-sorted.bam"
        os.system(aimap_tools.construct_bcftools_mpileup_cmdline(inbamfile,args.genomename,args.outdirname,args.outfile_name,args.threads))
        
        #Step6 Generate vcf for bcf file.
        logger.info("Step6 Generate vcf for bcf file.")
        bcf_file=args.outdirname+"/"+args.outfile_name+".bcf"
        os.system(aimap_tools.construct_bcftools_call_cmdline(bcf_file,args.outdirname,args.outfile_name,args.threads))
        
        #Step7 Vcf file filt.
        logger.info("Step7 Vcf file filt.")
        vcf_file=args.outdirname+"/"+args.outfile_name+".vcf"
        os.system(aimap_tools.construct_bcftools_view_cmdline(vcf_file,args.outdirname,args.outfile_name,args.threads))
     
        #Step8 Get DP and DP4 information.
        logger.info("Get DP and DP4 information.")
        vcf_filt_file=args.outdirname+"/"+args.outfile_name+"-filt.vcf"
        os.system(aimap_tools.construct_bcftools_query_cmdline(vcf_filt_file,args.outdirname,args.outfile_name))
        
        #Step7 Convert vcf file to table.
        logger.info("Step7 Convert vcf file to table.")
        tab_file=args.outdirname+"/"+args.outfile_name+".tab"
        aimap_tools.convert_pileup_to_table(tab_file,args.outdirname,args.outfile_name)
    	
        #Step10 Confirm whether the amino acid has changed.
        logger.info("Step10 Confirm whether the amino acid has changed.")
        a_i_file=args.outdirname+"/"+args.outfile_name+"_modification.txt"
        aimap_tools.get_founction_Prokaryote(a_i_file,args.outdirname,args.outfile_name,args.genomename,args.annotation)

        # Report that we've finished
        logger.info("Done: %s.", time.asctime())
        logger.info("Time taken: %.2fs", (time.time() - t0))
        
    if args.model == "paired":
        old_file1=os.path.splitext(os.path.split(args.filename1)[1])[0]
        old_file2=os.path.splitext(os.path.split(args.filename2)[1])[0]
        new_file1=args.outdirname+"/"+old_file1+"_val_1.fq"
        new_file2=args.outdirname+"/"+old_file2+"_val_2.fq"
        os.system(aimap_tools.construct_bwa_mem_paired_cmdline(args.genomename, new_file1,new_file2,args.outdirname,args.outfile_name,args.threads))
        
        #Step4 Sort the bam file.
        logger.info("Step4 Sort the bam file.")
        insamfile=args.outdirname+"/"+args.outfile_name+".sam"        
        os.system(aimap_tools.construct_samtools_sort_cmdline(insamfile,args.outdirname,args.outfile_name,args.threads)) 
                        
        #Step5 Generate bcf for one or multiple BAM files
        logger.info("Generate bcf for one or multiple BAM files")
        inbamfile=args.outdirname+"/"+args.outfile_name+"-sorted.bam"
        os.system(aimap_tools.construct_bcftools_mpileup_cmdline(inbamfile,args.genomename,args.outdirname,args.outfile_name,args.threads))
        
        #Step6 Generate vcf for bcf file.
        logger.info("Step6 Generate vcf for bcf file.")
        bcf_file=args.outdirname+"/"+args.outfile_name+".bcf"
        os.system(aimap_tools.construct_bcftools_call_cmdline(bcf_file,args.outdirname,args.outfile_name,args.threads))
        
        #Step7 Vcf file filt.
        logger.info("Step7 Vcf file filt.")
        vcf_file=args.outdirname+"/"+args.outfile_name+".vcf"
        os.system(aimap_tools.construct_bcftools_view_cmdline(vcf_file,args.outdirname,args.outfile_name,args.threads))
     
        #Step8 Get DP and DP4 information.
        logger.info("Get DP and DP4 information.")
        vcf_filt_file=args.outdirname+"/"+args.outfile_name+"-filt.vcf"
        os.system(aimap_tools.construct_bcftools_query_cmdline(vcf_filt_file,args.outdirname,args.outfile_name))
        
        #Step7 Convert vcf file to table.
        logger.info("Step7 Convert vcf file to table.")
        tab_file=args.outdirname+"/"+args.outfile_name+".tab"
        aimap_tools.convert_pileup_to_table(tab_file,args.outdirname,args.outfile_name)
    	
        #Step10 Confirm whether the amino acid has changed.
        logger.info("Step10 Confirm whether the amino acid has changed.")
        a_i_file=args.outdirname+"/"+args.outfile_name+"_modification.txt"
        aimap_tools.get_founction_Prokaryote(a_i_file,args.outdirname,args.outfile_name,args.genomename,args.annotation)

    		
        # Report that we've finished
        logger.info("Done: %s.", time.asctime())
        logger.info("Time taken: %.2fs", (time.time() - t0))



# try using distribute or setuptools or distutils.
try:
    import distribute_setup
    distribute_setup.use_setuptools()
except ImportError:
    pass

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os
import sys
import re

# parse version from package/module without importing or evaluating the code
with open('aimap/__init__.py') as fh:
    for line in fh:
        m = re.search(r"^__version__ = '(?P<version>[^']+)'$", line)
        if m:
            version = m.group('version')
            break

if sys.version_info <= (3, 0):
    sys.stderr.write("ERROR: aimap requires Python 3 " +
                     "or above...exiting.\n")
    sys.exit(1)

setup(
    name="aimap",
    version=version,
    author="Sai Wang",
    author_email="skyws@outlook.com",
    description=''.join(["aimap provides a package and script for " +
                         "finding the modification from Adenosine to inosine (A to I)."]),
    license="MIT",
    keywords="sequence analysis",
    platforms="Posix; MacOS X",
    url="https://github.com/castualwang/aimap",  # project home page
    download_url="https://github.com/castualwang/aimap/releases",
    scripts=[os.path.join('bin', 'Adenosine_to_inosine.py')],
    packages=['aimap'],
    package_data={'aimap': ['test_result/*.txt']},
    include_package_date=True,
    install_requires=['biopython',
                      'pandas',
                      'gffutils'],
    python_requires='>=3',                  
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        ],
    )
